app

package
v0.0.0-...-3929c03 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 5, 2026 License: MIT Imports: 1 Imported by: 1

Documentation

Overview

Package app implements application initialization and message loop that can be used in main goroutine only.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Post

func Post(f func()) error

Post put f into the UI message queue, f will run in the UI thread ASAP.

func Quit

func Quit(exitCode int)

Quit calls win32.PostQuitMessage which tells the message loop to exit. The exit code will be the return value of Run.

func Run

func Run() int

Run runs the message loop.

func SetMessageDispatcher

func SetMessageDispatcher(msgProc MsgProc)

SetMessageDispatcher sets a dispatcher for windows message dispatching. The default message dispatcher is [win32.DispatchMessageW].

Types

type MsgProc

type MsgProc = gwapp.MessageDispatcher

Directories

Path Synopsis
Package gwapp implements application initialization and message loop that can be used in any goroutine.
Package gwapp implements application initialization and message loop that can be used in any goroutine.

Jump to