Documentation
¶
Overview ¶
Package gwapp implements application initialization and message loop that can be used in any goroutine.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type GwApp ¶
type GwApp struct {
// contains filtered or unexported fields
}
func (*GwApp) Quit ¶
Quit calls win32.PostQuitMessage which tells the message loop to exit. The exit code will be the return value of Run.
func (*GwApp) SetMessageDispatcher ¶
func (app *GwApp) SetMessageDispatcher(dispatcher MessageDispatcher)
SetMessageDispatcher sets a dispatcher for windows message dispatching. The default message dispatcher is win32.DispatchMessageW.
type MessageDispatcher ¶
type MessageDispatcher func(msg *win32.MSG, prevProc func(msg *win32.MSG) win32.LRESULT) win32.LRESULT
MessageDispatcher is a function that dispatches Windows messages. The prevProc parameter is the previous message dispatcher in the chain, which can be called to continue the default message processing.
Click to show internal directories.
Click to hide internal directories.